Name:           tlp
Version:        1.6.1
Release:        %mkrel 1
Summary:        Advanced power management tool for Linux
Group:          System/Kernel and hardware
License:        GPLv2+
URL:            https://linrunner.de/en/tlp/tlp.html
Source0:        https://github.com/linrunner/TLP/archive/%{version}/TLP-%{version}.tar.gz
#Provided by Andreas Roederer <tlp~at~warpnine~dot~de>:
Source1:        50-tlp.preset
BuildArch:      noarch

BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  systemd

#The following requires are not detected:
Requires:       ethtool
Requires:       hdparm
Requires:       iw
Requires:       pciutils
Requires:       rfkill
Requires:       systemd
Requires:       udev
Requires:       usbutils
Requires:       util-linux >= 2.17
Requires:       wireless-tools

Recommends:     smartmontools

Requires(post):   rpm-helper >= %{rpmhelper_required_version}
Requires(preun):  rpm-helper >= %{rpmhelper_required_version}
Requires(postun): rpm-helper >= %{rpmhelper_required_version}

%description
TLP brings you the benefits of advanced power management for Linux
without the need to understand every technical detail. TLP comes
with a default configuration already optimized for battery life.
Also an optional install of the smartmontools package enables hard
disk SMART data in tlp-stat (smartctl).

%package rdw
Summary:        Radio Device Wizard for TLP
Group:          System/Kernel and hardware
BuildArch:      noarch
Requires:       NetworkManager
Requires:       %{name} = %{version}-%{release}

%description rdw
Radio Device Wizard for TLP automatically toggles wireless networking
based on dock events and the Network Manager connection status.

%prep
%autosetup -n TLP-%{version}

%build
%set_build_flags
%make_build

%install
%make_install install-man \
              TLP_NO_INIT=1 \
              TLP_NO_PMUTILS=1 \
              TLP_WITH_SYSTEMD=1 \
              TLP_WITH_ELOGIND=0 \
              TLP_SDSL=%{_usr}/lib/systemd/system-sleep \
              TLP_SYSD=%{_unitdir} \
              TLP_ULIB=%{_udevrulesdir}/..

#Install preset (source 1):
install -Dpm 0644 %{SOURCE1} %{buildroot}%{_presetdir}/50-tlp.preset

%post
%_post_service %{name}
%_post_service %{name}-sleep
systemctl mask systemd-rfkill.service

%preun
%_preun_service %{name}
%_preun_service %{name}-sleep

%postun
%_postun_service %{name}
%_postun_service %{name}-sleep
if [ $1 -eq 0 ] ; then
    systemctl unmask systemd-rfkill.service
fi

%post rdw
/bin/systemctl enable NetworkManager-dispatcher.service >/dev/null 2>&1 || :

%files
%doc README.rst
%license COPYING LICENSE
%config(noreplace) %{_sysconfdir}/tlp.conf
%{_sysconfdir}/tlp.d/
%{_bindir}/bluetooth
%{_bindir}/run-on-ac
%{_bindir}/run-on-bat
%{_bindir}/tlp-stat
%{_bindir}/wifi
%{_bindir}/nfc
%{_bindir}/wwan
%{_sbindir}/tlp
%{_datadir}/tlp/
%{_datadir}/bash-completion/completions/*
%{_datadir}/zsh/site-functions/_tlp
%{_datadir}/zsh/site-functions/_tlp-radio-device
%{_datadir}/zsh/site-functions/_tlp-run-on
%{_datadir}/zsh/site-functions/_tlp-stat
%{_datadir}/metainfo/de.linrunner.tlp.metainfo.xml
%{_udevrulesdir}/85-tlp.rules
%{_udevrulesdir}/../tlp-usb-udev
%{_presetdir}/50-tlp.preset
%{_unitdir}/tlp*.service
%{_usr}/lib/systemd/system-sleep/tlp
%{_mandir}/man1/*.1.*
%{_mandir}/man8/tlp*.8.*

%files rdw
%doc README.rst
%license COPYING LICENSE
%{_bindir}/tlp-rdw
%{_usr}/lib/NetworkManager/dispatcher.d/99tlp-rdw-nm
%{_datadir}/zsh/site-functions/_tlp-rdw
%{_udevrulesdir}/85-tlp-rdw.rules
%{_udevrulesdir}/../tlp-rdw-udev


%changelog
* Wed Sep 20 2023 daviddavid <daviddavid> 1.6.1-1.mga10
+ Revision: 1988431
- new version: 1.6.1

* Fri Sep 01 2023 daviddavid <daviddavid> 1.6.0-1.mga10
+ Revision: 1982950
- new version: 1.6.0

* Sun Aug 21 2022 papoteur <papoteur> 1.5.0-1.mga9
+ Revision: 1879054
- new 1.5.0

* Thu Mar 24 2022 umeabot <umeabot> 1.3.1-3.mga9
+ Revision: 1824216
- Mageia 9 Mass Rebuild

* Thu Feb 20 2020 umeabot <umeabot> 1.3.1-2.mga8
+ Revision: 1547373
- Mageia 8 Mass Rebuild

* Sat Feb 08 2020 daviddavid <daviddavid> 1.3.1-1.mga8
+ Revision: 1488049
- new version: 1.3.1

* Mon Feb 03 2020 daviddavid <daviddavid> 1.3.0-1.mga8
+ Revision: 1486620
- new version: 1.3.0
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Wed May 08 2019 daviddavid <daviddavid> 1.2.2-1.mga7
+ Revision: 1396656
- new version: 1.2.2

* Mon Mar 18 2019 daviddavid <daviddavid> 1.2.1-1.mga7
+ Revision: 1378710
- new version: 1.2.1

* Thu Mar 14 2019 daviddavid <daviddavid> 1.2-1.mga7
+ Revision: 1376086
- new version: 1.2

* Fri Oct 12 2018 pterjan <pterjan> 1.1-3.mga7
+ Revision: 1319735
- Drop dependencies which don't actually seem required and don't exist on some architectures

* Fri Sep 21 2018 umeabot <umeabot> 1.1-2.mga7
+ Revision: 1291860
- Mageia 7 Mass Rebuild

* Sun Jan 28 2018 daviddavid <daviddavid> 1.1-1.mga7
+ Revision: 1197528
- new version: 1.1

* Wed Aug 16 2017 daviddavid <daviddavid> 1.0-1.mga7
+ Revision: 1141203
- initial package tlp

